package com.xjgs.controller;

import com.xjgs.pacsDao.PacsMapper;
import com.xjgs.recordDao.ArchiveDetailMapper;
import com.xjgs.exception.BusinessException;
import com.xjgs.exception.ExceptionCode;
import com.xjgs.service.MakeUpPacsService;
import com.xjgs.service.PacsService;
import com.xjgs.util.JsonResult;
import com.xjgs.util.StringUtil;
import com.xjgs.vo.ArchiveMaster;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import java.util.List;
import java.util.Map;

/**
 * @BelongsProject: pacs
 * @BelongsPackage: com.xjgs.controller
 * @Author: ChenJ
 * @CreateTime: 2022-05-11  17:00
 */
@Api("补偿采集的相关接口")
@Controller
@ResponseBody
@RequestMapping("/makeUp")
public class MakeUpPacs {
    @Autowired
    ArchiveDetailMapper archiveDetailMapper;
    @Autowired
    PacsMapper pacsMapper;
    @Autowired
    MakeUpPacsService makeUpPacsService;

    /**
     * @description: 根据记账号补偿采集
     * @author: ChenJ
     * @date: 2022/5/11 17:24
     * @param:
     * @param patient 患者记账号
     * @return: java.util.Map<java.lang.String,java.lang.Object>
     **/
//    @ApiOperation("按需采集")
//    @GetMapping("/makeUpByPacs")
//    public Map<String, Object> makeUpByNeed(String patient) throws BusinessException {
//
//        // 先对参数进行校验，如果为空则抛出异常
//        if (StringUtil.isEmpty(patient)){
//            throw new BusinessException(ExceptionCode.WRONG_PARAMS);
//        }
//        // 声明Pacs操作类
//        PacsService pacsService = new PacsService();
//        // 调用采集
//        pacsService.fanshe(patient);
//        pacsService.uploadRadiation(patient);
//
//
//        // 声明返回
//        JsonResult jsonResult = new JsonResult();
//        jsonResult.setCode("200");
//        jsonResult.setMsg("调用成功，请稍等下载文件");
//        return  jsonResult.getDataMap();
//    }

    /**
     * @description: 根据出院时间按需采集
     * @params: startTime
     * @params: endTime
     * @author linjj
     * @date: 2023/7/25 14:34
     */
    @ApiOperation("按需采集")
    @GetMapping("/makeUpByPacsAndTime")
    public Map<String, Object> makeUpByNeed(String startTime,String endTime) throws BusinessException {
        //返回类
        JsonResult jsonResult = new JsonResult();
        // 先对参数进行校验，如果为空则抛出异常
        if (StringUtil.isEmpty(startTime)){
            throw new BusinessException(ExceptionCode.WRONG_PARAMS);
        }
        // 先对参数进行校验，如果为空则抛出异常
        if (StringUtil.isEmpty(endTime)){
            throw new BusinessException(ExceptionCode.WRONG_PARAMS);
        }
        //查询时间段内需要按需采集病历信息
        List<ArchiveMaster> archiveMasterList = archiveDetailMapper.getArchiveMasterList(startTime, endTime);
        if (archiveMasterList.size()==0){
            jsonResult.setCode("100");
            jsonResult.setMsg("该时间段内无采集病历");
            return  jsonResult.getDataMap();
        }
        //循环执行
        for (ArchiveMaster list:archiveMasterList){
            makeUpPacsService.getPacsPathList(list);
        }
        // 声明返回
        jsonResult.setCode("200");
        jsonResult.setMsg("调用成功，请稍等下载文件");
        return  jsonResult.getDataMap();
    }


}
